@@ -1,5 +1,6 @@
 from urlparse import urlparse
 import urllib2
+from django.core.files import File
 
 from django.forms.widgets import ClearableFileInput
 from django.core.files.storage import default_storage
@@ -27,9 +28,8 @@ class S3FileInput(ClearableFileInput):
         final_attrs = self.build_attrs(attrs)
         element_id = final_attrs.get('id')
 
-        if value:
-
-            file_url = value.url()
+        if isinstance(value, File):
+            file_url = value.url
         else:
             file_url = ''
 
